==> library-0.5.2-sources.jar: app/valuationcontrol/multimodule/library/records/VariableData.java <==
package app.valuationcontrol.multimodule.library.records;

import app.valuationcontrol.multimodule.library.constraints.EvenBrackets;
import app.valuationcontrol.multimodule.library.constraints.EvenParenthesis;
import app.valuationcontrol.multimodule.library.entities.Variable;
import app.valuationcontrol.multimodule.library.helpers.OpenAIHelperFunctions;
import jakarta.validation.constraints.NotEmpty;
import jakarta.validation.constraints.Pattern;
import java.util.List;

public record VariableData(
    Long id,
    @NotEmpty @Pattern(regexp = "^(?:[A-z]|[0-9]|[ ]|[%])*") String variableName,
    String variableDescription,
    Long variableAreaId,
    Long variableSubAreaId,
    @EvenParenthesis @EvenBrackets String variableFormula,
    @NotEmpty
        @Pattern(
            regexp = "input|calc|constant|check|single_result|kpi|sub_total_row|total_row",
            flags = Pattern.Flag.CASE_INSENSITIVE)
        String variableType,
    Integer row,
    Integer variableOrder,
    Integer variableDepth,
    boolean variableApplyToHistoricals,
    @NotEmpty
        @Pattern(regexp = "decimal|integer|percent|date", flags = Pattern.Flag.CASE_INSENSITIVE)
        String variableFormat,
    List<VariableValueData> variableValues,
    List<Long> variableDependencies,
    String evaluatedVariableFormula,
    Long originalId,
    String evaluatedXLformula,
    List<Object[]> historicalValues,
    List<Object[]> projectionValues,
    boolean modelledAtSegment,
    List<Object> singleOrConstantValue,
    List<Object> yearToDateValue,
    List<Object> yearToGoValue) {

  public boolean isSingleEntry() {
    if (Variable.CONSTANT_OR_SINGLE.contains(this.variableType)) {
      return true;
    } else {
      return false;
    }
  }

  public Double getValueInPeriod(Integer period, Integer segmentIndex) {
    if (isSingleEntry() && singleOrConstantValue.size() > 0) {
      return OpenAIHelperFunctions.getDoubleFromObject(singleOrConstantValue.get(segmentIndex), this);
    } else {
      if (period > 0
          && !projectionValues().isEmpty()
          && !(projectionValues().get(segmentIndex) == null))
        return OpenAIHelperFunctions.getDoubleFromObject(projectionValues.get(segmentIndex)[period], this);

      if (period < 0
          && !historicalValues().isEmpty()
          && !(historicalValues().get(segmentIndex) == null))
        return OpenAIHelperFunctions.getDoubleFromObject(historicalValues.get(segmentIndex)[period], this);
    }
    return null;
  }
}

==> library-0.5.5-sources.jar: app/valuationcontrol/multimodule/library/records/VariableData.java <==
package app.valuationcontrol.multimodule.library.records;

import app.valuationcontrol.multimodule.library.constraints.EvenBrackets;
import app.valuationcontrol.multimodule.library.constraints.EvenParenthesis;
import app.valuationcontrol.multimodule.library.entities.Variable;
import app.valuationcontrol.multimodule.library.helpers.OpenAIHelperFunctions;
import jakarta.validation.constraints.NotEmpty;
import jakarta.validation.constraints.Pattern;
import java.util.List;

public record VariableData(
    Long id,
    @NotEmpty @Pattern(regexp = "^(?:[A-z]|[0-9]|[ ]|[%])*") String variableName,
    String variableDescription,
    Long variableAreaId,
    Long variableSubAreaId,
    @EvenParenthesis @EvenBrackets String variableFormula,
    @NotEmpty
        @Pattern(
            regexp = "input|calc|constant|check|single_result|kpi|sub_total_row|total_row",
            flags = Pattern.Flag.CASE_INSENSITIVE)
        String variableType,
    Integer row,
    Integer variableOrder,
    Integer variableDepth,
    boolean variableApplyToHistoricals,
    @NotEmpty
        @Pattern(regexp = "decimal|integer|percent|date", flags = Pattern.Flag.CASE_INSENSITIVE)
        String variableFormat,
    List<VariableValueData> variableValues,
    List<Long> variableDependencies,
    String evaluatedVariableFormula,
    Long originalId,
    String evaluatedXLformula,
    List<Object[]> historicalValues,
    List<Object[]> projectionValues,
    boolean modelledAtSegment,
    List<Object> singleOrConstantValue,
    List<Object> yearToDateValue,
    List<Object> yearToGoValue) {

  public boolean isSingleEntry() {
    if (Variable.CONSTANT_OR_SINGLE.contains(this.variableType)) {
      return true;
    } else {
      return false;
    }
  }

  public Double getValueInPeriod(Integer period, Integer segmentIndex) {
    if (isSingleEntry() && singleOrConstantValue.size() > 0) {
      return OpenAIHelperFunctions.getDoubleFromObject(
          singleOrConstantValue.get(segmentIndex), this);
    } else {
      if (period > 0
          && !projectionValues().isEmpty()
          && !(projectionValues().get(segmentIndex) == null))
        return OpenAIHelperFunctions.getDoubleFromObject(
            projectionValues.get(segmentIndex)[period], this);

      if (period < 0
          && !historicalValues().isEmpty()
          && !(historicalValues().get(segmentIndex) == null))
        return OpenAIHelperFunctions.getDoubleFromObject(
            historicalValues.get(segmentIndex)[period], this);
    }
    return null;
  }
}
